@@ -4,6 +4,12 @@ using System.IO;
 using System.Xml;
 using Mono.Unix;
 
+#if FIXED_PANELAPPLET
+using Gnome;
+#elif !WIN32 && !MAC
+using _Gnome;
+#endif
+
 using Tomboy.Sync;
 
 namespace Tomboy
@@ -17,7 +23,7 @@ namespace Tomboy
 		static bool is_panel_applet = false;
 		static PreferencesDialog prefs_dlg;
 		static SyncDialog sync_dlg;
-#if ENABLE_DBUS
+#if ENABLE_DBUS || WIN32 || MAC
 		static RemoteControl remote_control;
 #endif
 		static Gtk.IconTheme icon_theme = null;
@@ -29,19 +35,19 @@ namespace Tomboy
 
 			TomboyCommandLine cmd_line = new TomboyCommandLine (args);
 
-#if ENABLE_DBUS // Run command-line earlier with DBus enabled
+#if ENABLE_DBUS || WIN32 || MAC // Run command-line earlier with DBus enabled
 			if (cmd_line.NeedsExecute) {
 				// Execute args at an existing tomboy instance...
 				cmd_line.Execute ();
 				return;
 			}
-#endif // ENABLE_DBUS
+#endif // ENABLE_DBUS || WIN32
 
-			Initialize ("tomboy", "Tomboy", "tomboy", args);
+			Initialize ("tomboy", "tomboy", "tomboy", args);
 
 			// Add private icon dir to search path
 			icon_theme = Gtk.IconTheme.Default;
-			icon_theme.AppendSearchPath (System.IO.Path.Combine (Defines.DATADIR, "tomboy/icons"));
+			icon_theme.AppendSearchPath (Path.Combine (Path.Combine (Defines.DATADIR, "tomboy"), "icons"));
 
 //   PluginManager.CheckPluginUnloading = cmd_line.CheckPluginUnloading;
 
@@ -63,7 +69,7 @@ namespace Tomboy
 				addin.Initialize ();
 			}
 
-#if !ENABLE_DBUS
+#if !ENABLE_DBUS && !WIN32 && !MAC
 			if (cmd_line.NeedsExecute) {
 				cmd_line.Execute ();
 			}
@@ -96,7 +102,7 @@ namespace Tomboy
 			        override_path :
 			        Environment.GetEnvironmentVariable ("TOMBOY_PATH");
 			if (note_path == null)
-				note_path = "~/.tomboy";
+				note_path = Services.NativeApplication.ConfDir;
 
 			// Tilde expand
 			return note_path.Replace ("~", Environment.GetEnvironmentVariable ("HOME"));
@@ -105,7 +111,9 @@ namespace Tomboy
 		static void RegisterPanelAppletFactory ()
 		{
 			// This will block if there is no existing instance running
-			Gnome.PanelAppletFactory.Register (typeof (TomboyApplet));
+#if !WIN32 && !MAC
+			PanelAppletFactory.Register (typeof (TomboyApplet));
+#endif
 		}
 
 		static void StartTrayIcon ()
@@ -131,15 +139,17 @@ namespace Tomboy
 			// it's likely that the Notification Area isn't available.  So
 			// instead, launch the Search All Notes window so the user can
 			// can still use Tomboy.
+#if !MAC
 			if (tray_icon_showing == false)
 				ActionManager ["ShowSearchAllNotesAction"].Activate ();
+#endif
 			
 			return false; // prevent GLib.Timeout from calling this method again
 		}
 
 		static void RegisterRemoteControl (NoteManager manager)
 		{
-#if ENABLE_DBUS
+#if ENABLE_DBUS || WIN32 || MAC
 			try {
 				remote_control = RemoteControlProxy.Register (manager);
 				if (remote_control != null) {
@@ -148,7 +158,7 @@ namespace Tomboy
 					// If Tomboy is already running, open the search window
 					// so the user gets some sort of feedback when they
 					// attempt to run Tomboy again.
-					RemoteControl remote = null;
+					IRemoteControl remote = null;
 					try {
 						remote = RemoteControlProxy.GetInstance ();
 						remote.DisplaySearch ();
@@ -241,9 +251,13 @@ namespace Tomboy
 		{
 			Gdk.Screen screen = null;
 			if (tray_icon != null) {
+#if WIN32 || MAC
+				screen = tray_icon.Tray.TomboyTrayMenu.Screen;
+#else
 				Gdk.Rectangle area;
 				Gtk.Orientation orientation;
 				tray_icon.GetGeometry (out screen, out area, out orientation);
+#endif
 			}
 			GuiUtils.ShowHelp("tomboy.xml", null,
 			                  screen,
@@ -285,6 +299,9 @@ namespace Tomboy
 			        Catalog.GetString ("Copyright \xa9 2004-2007 Alex Graveley");
 			about.Comments = Catalog.GetString ("A simple and easy to use desktop " +
 			                                    "note-taking application.");
+			Gtk.AboutDialog.SetUrlHook (delegate (Gtk.AboutDialog dialog, string link) {
+				Services.NativeApplication.OpenUrl (link);
+			}); 
 			about.Website = Defines.TOMBOY_WEBSITE;
 			about.WebsiteLabel = Catalog.GetString("Homepage");
 			about.Authors = authors;
@@ -413,7 +430,7 @@ namespace Tomboy
 			                "  --search [text]\t\tOpen the search all notes window with " +
 			                "the search text.\n");
 
-#if ENABLE_DBUS
+#if ENABLE_DBUS || WIN32 || MAC
 			usage +=
 			        Catalog.GetString (
 			                "  --new-note\t\t\tCreate and display a new note.\n" +
@@ -432,7 +449,7 @@ namespace Tomboy
 //     "  --check-plugin-unloading\tCheck if plugins are " +
 //     "unloaded properly.\n");
 
-#if !ENABLE_DBUS
+#if !ENABLE_DBUS && !WIN32 && !MAC
 			usage += Catalog.GetString ("D-BUS remote control disabled.\n");
 #endif
 
@@ -450,7 +467,7 @@ namespace Tomboy
 				bool quit = false;
 
 				switch (args [idx]) {
-#if ENABLE_DBUS
+#if ENABLE_DBUS || WIN32 || MAC
 				case "--new-note":
 					// Get optional name for new note...
 					if (idx + 1 < args.Length
@@ -518,7 +535,7 @@ namespace Tomboy
 					Console.WriteLine (unknown_opt, args [idx]);
 					quit = true;
 					break;
-#endif // ENABLE_DBUS
+#endif // ENABLE_DBUS || WIN32
 
 				case "--panel-applet":
 					panel_applet = true;
@@ -585,8 +602,8 @@ namespace Tomboy
 
 		public void Execute ()
 		{
-#if ENABLE_DBUS
-			RemoteControl remote = null;
+#if ENABLE_DBUS || WIN32 || MAC
+			IRemoteControl remote = null;
 			try {
 				remote = RemoteControlProxy.GetInstance ();
 			} catch (Exception e) {
@@ -690,7 +707,7 @@ namespace Tomboy
 
 				recent_changes.Present ();
 			}
-#endif // ENABLE_DBUS
+#endif // ENABLE_DBUS || WIN32
 		}
 	}
 }
